@@ -6,8 +6,8 @@
 
 #![crate_type = "lib"]
 
-#![feature(io)]
-#![feature(path)]
+#![feature(old_io)]
+#![feature(old_path)]
 #![feature(core)]
 #![allow(unused_must_use)]
 
